@@ -18,7 +18,7 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
 our @EXPORT = qw//;
 
-our $VERSION = '0.02';
+our $VERSION = '0.04';
 
 require XSLoader;
 XSLoader::load('List::Helpers::XS', $VERSION);
@@ -33,28 +33,36 @@ List::Helpers::XS - Perl extension to provide some usefull functions with arrays
 
   use List::Helpers::XS qw/ :shuffle :slice /;
 
-  my @slice = random_slice(\@list, $size);
+  my $slice = random_slice(\@list, $size); # returns array reference
 
   random_slice_void(\@list, $size);
 
   shuffle(\@list);
   shuffle(@list);
 
+  # the same for tied arrays
+
+  tie(@list, "MyPackage");
+  shuffle(@list);
+  shuffle(\@list);
+  random_slice_void(\@list, $size);
+  my $slice = random_slice(\@list, $size); # returns array reference
+
 =head1 DESCRIPTION
 
 This module provides some rare but usefull functions to work with arrays.
+It supports tied arrays.
 
 =head2 random_slice
 
 This method receives an array and amount of required elements from it,
-shuffles array's elements and returns the C<num> elements from it.
+shuffles array's elements and returns the array reference to the new
+arrays with C<num> elements from original one.
 
 If C<num> is equal or higher than amount of elements in array, then
 it won't do any work.
 
-Otherwise the original array will be truncated down to C<num> elements.
-
-It doesn't shuffle the whole array, it shuffle only C<num> elements and returns only them.
+It doesn't shuffle the whole array, it shuffles only C<num> elements and returns only them.
 
 Also the original array will be shuffled at the end.
 
@@ -72,7 +80,7 @@ In this case please consider the usage of C<random_slice_void> method.
 
 =head2 shuflle
 
-  Shuffle the provided array.
+  Shuffles the provided array.
   Doesn't return anything.
 
 =cut
@@ -86,9 +94,9 @@ with C<splice> method invocation afterwards.
 Total amount of elements in initial array: 250
 
                     Rate       shuffle_huge_array  random_slice  random_slice_void
-shuffle_huge_array  94967/s    --             -38%          -44%
-random_slice        152439/s   61%            --            -10%
-random_slice_void   168634/s   78%            11%           --
+shuffle_huge_array  94967/s    --                  -38%          -44%
+random_slice        152439/s   61%                 --            -10%
+random_slice_void   168634/s   78%                 11%           --
 
 
                    Rate       shuffle_array  random_slice  random_slice_void
